<?php
/**
 * Contains useful functions for WordPress
 * @Author Paul Stelzer
 * @package InnoMobile
 * @version 1.1.0
 */
namespace InnoMobile;
use \WP_Query;

if ( !class_exists( 'InnoMobile\Functions') ) :
class Functions {

    /**
     * Receive the first term of a taxonomy in post
     * @param type $post_id
     * @param type $taxonomy
     * @param type $return What should be returned? name or slug
     * @return string first term
     */
    public static function get_first_term($post_id, $taxonomy, $return = 'name') {       
        $terms = get_the_terms( $post_id, $taxonomy );
        if ( $terms && ! is_wp_error( $terms ) ) {
            foreach ( $terms as $term ) {
                if($return=='name') {
                    return $term->name;
                }
                if($return=='slug') {
                    return $term->slug;
                }
            }
        }
        
        return '';

    }
    
    /**
     * Get all posts by post type
     * @param type $post_type WP Post Type
     * @param type $posts_per_page How many posts hould be shown (-1 = all)
     * @return array posts
     */
    public static function get_all_posts_by_post_type($post_type = 'post', $posts_per_page = -1) {
        //Query all  IDs and Title
        $posts = array();
        $query = new WP_Query( array( 'post_type' => $post_type, 'post_status' => 'publish', 'order' => 'ASC', 'orderby' => 'title', 'posts_per_page'=>$posts_per_page ) );
        if ( $query->have_posts() ) {
            while ( $query->have_posts() ) {
                    $query->the_post();
                    
                    $posts[] = array(
                        'ID' => get_the_ID(),
                        'title' => get_the_title(),
                    );
            }
        }
        /* Restore original Post Data */
        wp_reset_postdata();            

        return $posts;
    }
    
    /**
     * Get all terms of post of custom taxonomy (only name, no link)
     * @param type $post_id
     * @param type $taxonomy
     * @return type
     */
    public static function get_terms($post_id, $taxonomy) {
        $elements = '';
        $terms = get_the_terms($post_id, $taxonomy);
        if ($terms && !is_wp_error($terms)) {
            $element = array();
            foreach ($terms as $term) {
                $element[] = $term->name;
            }
            $elements = join(", ", $element);
        }

        return $elements;
    }
    
    /**
     * Get correct count posts of WP Query
     * @param type $args Arguments for WP QUERY
     * @return type
     */
    public static function count_posts($args) {
        $custom_posts = new WP_Query($args);
        //print_r($args);
        //echo "Last SQL-Query: {$custom_posts->request}";
        $count = $custom_posts->post_count;

        if ($count == 10) {
            $found_posts = $custom_posts->found_posts;
            if ($found_posts > $count)
                $count = $found_posts;
        }
        wp_reset_query();

        return $count;
    }
    
    /**
     * Get ID of first post
     * @param type $args
     * @return type
     */
    public static function get_ID_of_first_post($args) {
        $custom_posts = new WP_Query($args);

        //print_r($args);
        //echo "Last SQL-Query: {$custom_posts->request}";
        $ID = $custom_posts->posts[0]->ID;
        wp_reset_query();

        return $ID;
    }
    
    /**
     * Get newest date (published or modified date)
     * @param type $format
     */
    public static function newest_date($format = '') {
        $date1 = get_the_modified_date('Y-m-d');
        $date2 = get_the_date('Y-m-d');

        if ($date1 > $date2)
            $datum = get_the_modified_date($format);
        else
            $datum = get_the_date($format);
        echo $datum;
    }
    
    /**
     * Array of all public post types
     * @return array post_types
     */
    public static function get_public_post_types() {
            $args = array(
               'public'   => true
            );
            $post_types = get_post_types( $args ); 

            $array_post_type = array(); 
            foreach ( $post_types  as $post_type ) {
               $array_post_type[$post_type] = $post_type;
            }
            return $array_post_type;
    }
    
    /**
     * Array of all public taxonomies
     * @return array taxonomies
     */
    public static function get_public_taxonomies() {
            $args = array(
               'public'   => true
            );
            $taxonomies = get_taxonomies( $args ); 

            $array_taxonomies = array(); 
            foreach ( $taxonomies  as $taxonomy ) {
               $array_taxonomies[$taxonomy] = $taxonomy;
            }
            return $array_taxonomies;
    }
}
endif;